irl\_benchmark.metrics package
==============================

Submodules
----------

irl\_benchmark.metrics.avg\_traj\_return module
-----------------------------------------------

.. automodule:: irl_benchmark.metrics.avg_traj_return
    :members:
    :undoc-members:
    :show-inheritance:

irl\_benchmark.metrics.base\_metric module
------------------------------------------

.. automodule:: irl_benchmark.metrics.base_metric
    :members:
    :undoc-members:
    :show-inheritance:

irl\_benchmark.metrics.feature\_count\_inf module
-------------------------------------------------

.. automodule:: irl_benchmark.metrics.feature_count_inf
    :members:
    :undoc-members:
    :show-inheritance:

irl\_benchmark.metrics.feature\_count\_l2 module
------------------------------------------------

.. automodule:: irl_benchmark.metrics.feature_count_l2
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: irl_benchmark.metrics
    :members:
    :undoc-members:
    :show-inheritance:
